@@ -3,6 +3,5 @@ from kpl_helper.parameter import (
     write_parameter,
 )
 
-from kpl_helper import metric, result, progress, io
+from kpl_helper import metric, result, progress, io, deploy
 from kpl_helper.base import ready, done
-
